package com.yanzuoguang.util.exception;


/**
 * 状态异常错误
 * @author 颜佐光
 */
public class StatusException extends RuntimeException {

    /**
     * 错误状态码
     */
    private int status;

    /**
     * 错误结果
     */
    private Object result;

    /**
     * 状态异常错误
     */
    public StatusException() {
        super();
    }

    /**
     * Constructs a new runtime exception with the specified detail message.
     * The cause is not initialized, and may subsequently be initialized by a
     * call to {@link #initCause}.
     *
     * @param message the detail message. The detail message is saved for
     *                later retrieval by the {@link #getMessage()} method.
     */
    public StatusException(String message) {
        super(message);
    }

    /**
     * Constructs a new runtime exception with the specified detail message and
     * cause.  <p>Note that the detail message associated with
     * {@code cause} is <i>not</i> automatically incorporated in
     * this runtime exception's detail message.
     *
     * @param message the detail message (which is saved for later retrieval
     *                by the {@link #getMessage()} method).
     * @param cause   the cause (which is saved for later retrieval by the
     *                {@link #getCause()} method).  (A <tt>null</tt> value is
     *                permitted, and indicates that the cause is nonexistent or
     *                unknown.)
     * @since 1.4
     */
    public StatusException(String message, Throwable cause) {
        super(message, cause);
    }

    /**
     * Constructs a new runtime exception with the specified cause and a
     * detail message of <tt>(cause==null ? null : cause.toString())</tt>
     * (which typically contains the class and detail message of
     * <tt>cause</tt>).  This constructor is useful for runtime exceptions
     * that are little more than wrappers for other throwables.
     *
     * @param cause the cause (which is saved for later retrieval by the
     *              {@link #getCause()} method).  (A <tt>null</tt> value is
     *              permitted, and indicates that the cause is nonexistent or
     *              unknown.)
     * @since 1.4
     */
    public StatusException(Throwable cause) {
        super(cause);
    }

    /**
     * Constructs a new runtime exception with the specified detail
     * message, cause, suppression enabled or disabled, and writable
     * stack trace enabled or disabled.
     *
     * @param message            the detail message.
     * @param cause              the cause.  (A {@code null} value is permitted,
     *                           and indicates that the cause is nonexistent or unknown.)
     * @param enableSuppression  whether or not suppression is enabled
     *                           or disabled
     * @param writableStackTrace whether or not the stack trace should
     *                           be writable
     * @since 1.7
     */
    protected StatusException(String message, Throwable cause,
                              boolean enableSuppression,
                              boolean writableStackTrace) {
        super(message, cause, enableSuppression, writableStackTrace);
    }

    /**
     * 途必达自定义异常
     *
     * @param status   错误码
     * @param format 格式化字符串
     * @param paras  参数
     */
    public StatusException(int status, String format, Object... paras) {
        super(String.format(format, paras));
        this.result = null;
        this.status = status;
    }

    /**
     * 途必达自定义异常
     *
     * @param result 结果
     * @param status   错误码
     * @param format 格式化字符串
     * @param paras  参数
     */
    public StatusException(Object result, int status, String format, Object... paras) {
        super(String.format(format, paras));
        this.result = result;
        this.status = status;
    }

    /**
     * 获取状态
     * @return
     */
    public int getStatus() {
        return status;
    }

    /**
     * 状态码
     * @param status
     */
    public void setStatus(int status) {
        this.status = status;
    }

    /**
     * 结果
     * @return
     */
    public Object getResult() {
        return result;
    }

    /**
     * 结果
     * @param result
     */
    public void setResult(Object result) {
        this.result = result;
    }
}
